.. _matrices-docs:

========
Matrices
========

.. automodule:: sympy.matrices

Contents:

.. toctree::
   :titlesonly:

   matrices.rst
   common.rst
   dense.rst
   sparse.rst
   sparsetools.rst
   immutablematrices.rst
   expressions.rst
   normalforms.rst
